@@ -10,23 +10,24 @@
 #include "processdialog.h"
 #include "ui_processdialog.h"
 
-#include "writewindow.h"
-#include "ui_writewindow.h"
-
-#include <QMessageBox>
+#include "comparedialog.h"
+#include "ui_comparedialog.h"
 
 configReader::configReader(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::configReader)
 {
     ui->setupUi(this);
-    // Set startLabel text color to black
-    ui->startLabel->setStyleSheet("color: black;");
+    // Set startLbl text color to black
+    ui->startLbl->setStyleSheet("color: black;");
     // Set the background
     this->setStyleSheet("QMainWindow { background-image: url(:/gfx/backstart.png) }");
     // Make the top menu
     setupCRMenu();
 
+    // Reset cameFrom, will be decided in dialogs
+    cameFrom = "";
+
     // Read GConf values after clearing them
     saveDirConf.clear();
     saveDir = "/home/user/MyDocs";
@@ -40,8 +41,10 @@ configReader::configReader(QWidget *parent) :
     dateFormatTitle.clear(); // For html document title
     getDateFormat();
 
-    connect(ui->startBtn, SIGNAL(clicked()),
+    connect(ui->newBtn, SIGNAL(clicked()),
             this, SLOT(openProcDialog()));
+    connect(ui->compareBtn, SIGNAL(clicked()),
+            this, SLOT(openCompDialog()));
 }
 configReader::~configReader() {
     delete ui;
@@ -90,7 +93,7 @@ void configReader::saveDirReadReady() {
     saveDir.setPath(saveDirConf);
 
     // If the path doesn't contain /home/user/MyDocs, make it /home/user/MyDocs
-    if(!saveDir.absolutePath().contains("/home/user/MyDocs"))
+    if( ! saveDir.absolutePath().contains("/home/user/MyDocs"))
         saveDir.setPath("/home/user/MyDocs");
     // If the path is invalid, set it on /home/user/MyDocs
     if(saveDir.exists() == false)
@@ -146,10 +149,10 @@ void configReader::dateReadReady() {
     dateFormat.append(dateProcess.readAllStandardOutput());
 
     // If dateFormat is invalid, set it on default and store it in GConf
-    if(!dateFormat.contains("ddMMyyyy", Qt::CaseSensitive)
-        && !dateFormat.contains("MMddyyyy", Qt::CaseSensitive)
-        && !dateFormat.contains("yyyyddMM", Qt::CaseSensitive)
-        && !dateFormat.contains("yyyyMMdd", Qt::CaseSensitive)) {
+    if( ! dateFormat.contains("ddMMyyyy", Qt::CaseSensitive)
+        && ! dateFormat.contains("MMddyyyy", Qt::CaseSensitive)
+        && ! dateFormat.contains("yyyyddMM", Qt::CaseSensitive)
+        && ! dateFormat.contains("yyyyMMdd", Qt::CaseSensitive)) {
             dateFormat == "ddMMyyyy";
             system("gconftool -s /apps/maemo/configreader/date_format -t string \"ddMMyyyy\"");
     }
@@ -189,8 +192,6 @@ void configReader::openProcDialog() {
     // Open the dialog for processing "gconftool -R /"
     procDialog = new processDialog(this);
     procDialog->setAttribute(Qt::WA_DeleteOnClose);
-    connect(procDialog, SIGNAL(destroyed()),
-            this, SLOT(openWriteWin()));
     procDialog->show();
     procDialog->gconfStart();
 }
@@ -199,10 +200,8 @@ void configReader::openProcDialog() {
 
 
 
-void configReader::openWriteWin() {
-    // Open the window for HTML writing
-    writeWin = new writeWindow(this);
-    writeWin->setAttribute(Qt::WA_Maemo5StackedWindow);
-    writeWin->setAttribute(Qt::WA_DeleteOnClose);
-    writeWin->show();
+void configReader::openCompDialog() {
+    compDialog = new compareDialog(this);
+    compDialog->setAttribute(Qt::WA_DeleteOnClose);
+    compDialog->show();
 }
