@@ -4,13 +4,15 @@
 #include <QMainWindow>
 #include <QProcess>
 #include <QDir>
+#include <QFile>
 #include <QMenu>
 #include <QMenuBar>
+#include <QMessageBox>
 
 class aboutDialog;
 class settingsDialog;
 class processDialog;
-class writeWindow;
+class compareDialog;
 
 namespace Ui {
     class configReader;
@@ -24,13 +26,24 @@ public:
     explicit configReader(QWidget *parent = 0);
     ~configReader();
 
-    QString saveDirConf;
-    QDir saveDir;
+    // processDialog, writeWindow
     QString outData;
+    // settingsDialog, writeWindow
     QString dateFormat;
     QString dateFormatTitle;
-    QString dateSepConf;
+    bool carAnim;
+    // settingsDialog
     QString dateSep;
+    // compareDialog, writeWindow
+    QDir saveDir;
+    QFile fileWithPath1;
+    QFile fileWithPath2;
+    QString fileCont1;
+    QString fileCont2;
+    // compareDialog, processDialog, writeWindow
+    QString cameFrom;
+
+    // settingsDialog
     void setDateFormatTitle();
 
 public slots:
@@ -39,7 +52,7 @@ public slots:
     void dateReadReady();
 
     void openProcDialog();
-    void openWriteWin();
+    void openCompDialog();
 
     void createAboutDialog();
     void createAboutQtDialog();
@@ -50,6 +63,9 @@ private:
 
     int i;
 
+    QString saveDirConf;
+    QString dateSepConf;
+
     QProcess saveDirProcess;
     QProcess sepProcess;
     QProcess dateProcess;
@@ -58,7 +74,7 @@ private:
     aboutDialog *abtDialog;
     settingsDialog *settDialog;
     processDialog *procDialog;
-    writeWindow *writeWin;
+    compareDialog *compDialog;
 
     void setupCRMenu();
     void getSaveDir();
