@@ -4,14 +4,18 @@
 #include "configreader.h"
 #include "ui_configreader.h"
 
+#include "writewindow.h"
+#include "ui_writewindow.h"
+
 processDialog::processDialog(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::processDialog)
 {
-    ui->setupUi(this);
-    // procParent is a pointer to processWindow's parent (configReader)
+    // procParent is a pointer to processDialog's parent (configReader)
     procParent = (configReader*) parent;
 
+    ui->setupUi(this);
+
     procParent->outData = "";
 
     connect(&gconfProcess, SIGNAL(readyReadStandardOutput()),
@@ -51,7 +55,14 @@ void processDialog::gconfWrite() {
 
 
 void processDialog::gconfFinished() {
-    // Stop the process
+    // Stop the process, close this dialog
     gconfProcess.close();
     this->close();
+
+    // Open the window for HTML writing
+    writeWin = new writeWindow(procParent);
+    writeWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+    writeWin->setAttribute(Qt::WA_DeleteOnClose);
+    procParent->cameFrom = "process";
+    writeWin->show();
 }
