@@ -5,6 +5,7 @@
 #include <QProcess>
 
 class configReader;
+class writeWindow;
 
 namespace Ui {
     class processDialog;
@@ -17,7 +18,7 @@ class processDialog : public QDialog
 public:
     explicit processDialog(QWidget *parent = 0);
     ~processDialog();
-    // Start the process from another class
+
     void gconfStart();
 
 public slots:
@@ -27,6 +28,7 @@ public slots:
 private:
     Ui::processDialog *ui;
     configReader *procParent;
+    writeWindow* writeWin;
 
     QProcess gconfProcess;
 };
