@@ -8,16 +8,16 @@ settingsDialog::settingsDialog(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::settingsDialog)
 {
+    // settParent is settingsDialog's parent (configReader)
+    settParent = (configReader*) parent;
+
     ui->setupUi(this);
     ui->filenameExLbl->setStyleSheet("color: deepskyblue;");
     ui->titleExLbl->setStyleSheet("color: deepskyblue;");
 
-    // settParent is settDialog's parent (configReader)
-    settParent = (configReader*) parent;
-
     ui->explLbl->adjustSize();
 
-    // Set dateFormat radiobuttons acoording to current values
+    // Set dateFormat radiobuttons acoording to current value
     ui->radDDMMYYYY->setChecked(false);
     ui->radMMDDYYYY->setChecked(false);
     ui->radYYYYDDMM->setChecked(false);
@@ -31,7 +31,7 @@ settingsDialog::settingsDialog(QWidget *parent) :
     else if(settParent->dateFormat == "yyyyMMdd")
         ui->radYYYYMMDD->setChecked(true);
 
-    // Set separator radiobuttons according to current values
+    // Set separator radiobuttons according to current value
     ui->sepDash->setChecked(false);
     ui->sepSlash->setChecked(false);
     ui->sepNone->setChecked(false);
@@ -58,7 +58,7 @@ settingsDialog::settingsDialog(QWidget *parent) :
     connect(ui->sepNone, SIGNAL(toggled(bool)),
             this, SLOT(sepNone()));
 
-    connect(this->ui->btnBox, SIGNAL(accepted()),
+    connect(ui->btnBox, SIGNAL(accepted()),
             this, SLOT(close()));
 
     // Update the radiobuttons and examples
@@ -142,7 +142,7 @@ void settingsDialog::updateRadioBtns() {
 
 void settingsDialog::updateExamples() {
     // configreaderDDMMYYYY-HHMMSS.html
-    ui->filenameExLbl->setText("configreader"
+    ui->filenameExLbl->setText("cread"
                                + settParent->dateFormat.toUpper()
                                + "-HHMMS.html");
     // DD-MM-YYYY, HH:MM:SS (Config Reader)
