@@ -8,6 +8,9 @@
 #include <QDate>
 #include <QTime>
 #include <QFile>
+#include <QFileDialog>
+#include <QDesktopServices>
+#include <QUrl>
 
 class configReader;
 
@@ -25,12 +28,15 @@ public:
 
 public slots:
     void writeFile();
+    void openFile();
 
 private:
     Ui::writeWindow *ui;
     configReader *writeParent;
 
     int i;
+    int bodyTagPos;
+    QString preSaveFileName;
     QFile saveFile;
     QDir bkpDir;
     QTextStream writeStrm;
@@ -43,8 +49,22 @@ private:
     int percDone; // Percentage for the progressbar
     float fPercDone; // Float version of percDone
     int carPos;
+    QString fileCopy1;
+    QString fileCopy2;
+    QStringList fileContSplitted1;
+    QStringList fileContSplitted2;
+    QStringList fileDiffList;
+    QString preDirString;
+    QString dirString;
+    QString fileDiff;
+    enum fileNumber {
+        first,
+        second
+    } sourceNum;
 
     void editOutData();
+    void outputDiff();
+    void saveDifference(QStringList &source, QStringList &compare);
 };
 
 #endif // WRITEWINDOW_H
